@@ -52,7 +52,8 @@ eib_plot_ggplot <- function(he,
   ##TODO: can we move this up a level?
   cri_params <- eib_params_cri(he, graph_params)
   
-  theme_add <- purrr::keep(extra_params, is.theme)
+  theme_add <- Filter(f = \(val) ggplot2::is.theme(val), x = extra_params)
+  
   legend_params <- make_legend_ggplot(he, graph_params$pos)
   graph_params <- eib_params_ggplot(he, graph_params, cri_params)
   
@@ -61,7 +62,7 @@ eib_plot_ggplot <- function(he,
       k = c(he$k),
       eib = c(he$eib), 
       comparison =
-        as.factor(rep(1:he$n_comparison,
+        as.factor(rep(1:he$n_comparisons,
                       each = length(he$k))))
   
   ggplot(data_psa,
@@ -72,6 +73,10 @@ eib_plot_ggplot <- function(he,
     theme_eib() +
     theme_add +
     do.call(theme, legend_params) +
+    do.call(theme, list(
+      axis.text = element_text(size = graph_params$text$size),
+      axis.title.x = element_text(size = graph_params$text$size),
+      axis.title.y = element_text(size = graph_params$text$size))) +
     do.call(labs,
             list(title = graph_params$main,
                  x = graph_params$xlab,
